<template>
  <a-card :bordered="false">
    <!-- 查询区域 -->
    <div class="table-page-search-wrapper">
      <a-form layout="inline" @keyup.enter.native="searchQuery">
        <a-row :gutter="24">
          <a-col :md="6" :sm="12">
            <a-form-item label="名称">
              <j-input placeholder="输入名称模糊查询" v-model="queryParam.name"></j-input>
            </a-form-item>
          </a-col>
          <template v-if="toggleSearchStatus">

          </template>
          <a-col :xl="6" :lg="7" :md="8" :sm="24">
            <span style="float: left;overflow: hidden;" class="table-page-search-submitButtons">
              <a-button type="primary" @click="searchQuery" icon="search">查询</a-button>
              <a-button type="primary" @click="searchReset" icon="reload" style="margin-left: 8px">重置</a-button>
              <a @click="handleToggleSearch" style="margin-left: 8px">
                {{ toggleSearchStatus ? '收起' : '展开' }}
                <a-icon :type="toggleSearchStatus ? 'up' : 'down'" />
              </a>
            </span>
          </a-col>
        </a-row>
      </a-form>
    </div>
    <!-- 查询区域-END -->

    <!-- 操作按钮区域 -->
    <div class="table-operator">
      <a-button @click="handleAdd" type="primary" icon="plus">新增</a-button>
      <a-button type="primary" icon="download" @click="handleExportXls('lims_item_target')">导出</a-button>
      <a-upload name="file" :showUploadList="false" :multiple="false" :headers="tokenHeader" :action="importExcelUrl"
        @change="handleImportExcel">
        <a-button type="primary" icon="import">导入</a-button>
      </a-upload>
      <!-- 高级查询区域 -->
      <j-super-query :fieldList="superFieldList" ref="superQueryModal"
        @handleSuperQuery="handleSuperQuery"></j-super-query>
      <a-dropdown v-if="selectedRowKeys.length > 0">
        <a-menu slot="overlay">
          <a-menu-item key="1" @click="batchDel"><a-icon type="delete" />删除</a-menu-item>
        </a-menu>
        <a-button style="margin-left: 8px"> 批量操作 <a-icon type="down" /></a-button>
      </a-dropdown>
    </div>

    <!-- table区域-begin -->
    <div>
      <div class="ant-alert ant-alert-info" style="margin-bottom: 16px;">
        <i class="anticon anticon-info-circle ant-alert-icon"></i> 已选择 <a style="font-weight: 600">{{
          selectedRowKeys.length }}</a>项
        <a style="margin-left: 24px" @click="onClearSelected">清空</a>
      </div>

      <a-table ref="table" size="middle" :scroll="{ x: true }" bordered rowKey="id" :columns="columns"
        :dataSource="dataSource" :pagination="ipagination" :loading="loading"
        :rowSelection="{ selectedRowKeys: selectedRowKeys, onChange: onSelectChange }" class="j-table-force-nowrap"
        @change="handleTableChange">

        <template slot="htmlSlot" slot-scope="text">
          <div v-html="text"></div>
        </template>
        <template slot='enabled' slot-scope='text, record'>
          <j-switch :value='text' @change="onSwCellChange(record.id, 'enabled', $event)"
            style='min-width: 80px'></j-switch>
        </template>
        <template slot="imgSlot" slot-scope="text">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无图片</span>
          <img v-else :src="getImgView(text)" height="25px" alt=""
            style="max-width:80px;font-size: 12px;font-style: italic;" />
        </template>
        <template slot="fileSlot" slot-scope="text">
          <span v-if="!text" style="font-size: 12px;font-style: italic;">无文件</span>
          <a-button v-else :ghost="true" type="primary" icon="download" size="small" @click="downloadFile(text)">
            下载
          </a-button>
        </template>

        <span slot="action" slot-scope="text, record">
          <a @click="handleEdit(record)">编辑</a>

          <a-divider type="vertical" />
          <a-dropdown>
            <a class="ant-dropdown-link">更多 <a-icon type="down" /></a>
            <a-menu slot="overlay">
              <a-menu-item>
                <a @click="handleDetail(record)">详情</a>
              </a-menu-item>
              <a-menu-item>
                <a-popconfirm title="确定删除吗?" @confirm="() => handleDelete(record.id)">
                  <a>删除</a>
                </a-popconfirm>
              </a-menu-item>
            </a-menu>
          </a-dropdown>
        </span>

      </a-table>
    </div>

    <!--    <lims-item-target-modal ref="modalForm" @ok="modalFormOk"></lims-item-target-modal>-->
    <lims-item-target-tech-modal :standId='standId' ref="modalForm" @ok="modalFormOk"></lims-item-target-tech-modal>
  </a-card>
</template>

<script>
import '@/assets/less/TableExpand.less'
import { JeecgListMixin } from '@/mixins/JeecgListMixin'
import { mixinDevice } from '@/utils/mixin'
import { editItemTarget } from '@api/lims'
import LimsItemTargetModal from './modules/LimsItemTargetModal'
import LimsItemTargetTechModal from './modules/LimsItemTargetTechModal'

export default {
  name: 'LimsItemTargetList',
  mixins: [JeecgListMixin, mixinDevice],
  components: {
    LimsItemTargetModal,
    LimsItemTargetTechModal
  },
  props: {
    standId: {
      type: String,
      required: true
    }

  },
  data() {
    return {
      description: '技术指标',
      queryParam: {
        isTech: 1,
        standardId: this.standId
      },
      // 表头
      columns: [
        {
          title: '#',
          dataIndex: '',
          key: 'rowIndex',
          width: 60,
          align: "center",
          customRender: function (t, r, index) {
            return parseInt(index) + 1;
          }
        },
        /* {
           title:'技术标准',
           align:"center",
           dataIndex: 'standardId_dictText'
         },
         {
           title:'鉴定大纲',
           align:"center",
           dataIndex: 'outlineId_dictText'
         },
         {
           title:'鉴定类别',
           align:"center",
           dataIndex: 'categoryId_dictText'
         },
         {
           title:'鉴定类型',
           align:"center",
           dataIndex: 'typeId_dictText'
         },
         {
           title:'鉴定项目',
           align:"center",
           dataIndex: 'itemId_dictText'
         },
         {
           title:'项目名称',
           align:"center",
           dataIndex: 'itemName'
         },*/
        {
          title: '编码',
          align: "center",
          dataIndex: 'code'
        },
        {
          title: '名称',
          align: "center",
          dataIndex: 'name'
        },
        {
          title: '值类型',
          align: "center",
          dataIndex: 'valType_dictText'
        },
        {
          title: '单位',
          align: "center",
          dataIndex: 'unit'
        },
        {
          title: '最大值',
          align: "center",
          dataIndex: 'max'
        },
        {
          title: '典型值',
          align: "center",
          dataIndex: 'typ'
        },
        {
          title: '最小值',
          align: "center",
          dataIndex: 'min'
        },
        {
          title: '判定依据',
          align: "center",
          dataIndex: 'judgment'
        },
        // {
        //   title:'是否证判',
        //   align:"center",
        //   dataIndex: 'isJudge'
        // },
        {
          title: '启用状态',
          align: "center",
          dataIndex: 'enabled',
          scopedSlots: { customRender: 'enabled' }
        },
        {
          title: '备注',
          align: "center",
          dataIndex: 'remark'
        },
        {
          title: '操作',
          dataIndex: 'action',
          align: "center",
          fixed: "right",
          width: 147,
          scopedSlots: { customRender: 'action' }
        }
      ],
      url: {
        list: "/lims/testing/target/list",
        delete: "/lims/testing/target/delete",
        deleteBatch: "/lims/testing/target/deleteBatch",
        exportXlsUrl: "/lims/testing/target/exportXls",
        importExcelUrl: "/lims/testing/target/importExcel",

      },
      dictOptions: {},
      superFieldList: [],
    }
  },
  created() {
    this.getSuperFieldList();
  },
  computed: {
    importExcelUrl: function () {
      return `${window._CONFIG['domianURL']}/${this.url.importExcelUrl}`;
    },
  },
  methods: {
    initDictConfig() {
    },
    getSuperFieldList() {
      let fieldList = [];
      fieldList.push({ type: 'sel_search', value: 'standardId', text: '技术标准', dictTable: '', dictText: '', dictCode: '' })
      fieldList.push({ type: 'sel_search', value: 'outlineId', text: '鉴定大纲', dictTable: '', dictText: '', dictCode: '' })
      fieldList.push({ type: 'sel_search', value: 'categoryId', text: '鉴定类别', dictTable: '', dictText: '', dictCode: '' })
      fieldList.push({ type: 'sel_search', value: 'typeId', text: '鉴定类型', dictTable: '', dictText: '', dictCode: '' })
      fieldList.push({ type: 'sel_search', value: 'itemId', text: '鉴定项目', dictTable: '', dictText: '', dictCode: '' })
      fieldList.push({ type: 'string', value: 'itemName', text: '项目名称', dictCode: '' })
      fieldList.push({ type: 'string', value: 'unit', text: '单位', dictCode: '' })
      fieldList.push({ type: 'double', value: 'max', text: '最大值', dictCode: '' })
      fieldList.push({ type: 'double', value: 'typ', text: '典型值', dictCode: '' })
      fieldList.push({ type: 'double', value: 'min', text: '最小值', dictCode: '' })
      fieldList.push({ type: 'string', value: 'judgment', text: '判定依据', dictCode: '' })
      fieldList.push({ type: 'int', value: 'isJudge', text: '是否证判', dictCode: '' })
      fieldList.push({ type: 'int', value: 'enabled', text: '启用状态', dictCode: '' })
      fieldList.push({ type: 'string', value: 'remark', text: '备注', dictCode: '' })
      this.superFieldList = fieldList
    },
    searchReset() {
      this.queryParam = { isTech: 1, standardId: this.standId }
      this.loadData(1)
    },
    onSwCellChange(id, dataIndex, value) {
      const dataSource = [...this.dataSource]
      const target = dataSource.find(item => item.id === id)
      if (target) {
        target[dataIndex] = value
      }
      this.editItem(target)
    },

    //编辑一行数据
    editItem(item) {
      editItemTarget(item).then(res => {
        if (res.success) {
          this.$message.success('操作成功！')
          //编辑成功后重新加载数据
          //this.queryItemTarget(this.currSelected)
        }

      })

    },
  }
}
</script>
<style scoped>
@import '~@assets/less/common.less';
</style>